@@ -41,7 +41,7 @@
 #' # Conduct network meta-analysis with placebo as reference treatment
 #' #
 #' net1 <- netmeta(TE, seTE, treat1, treat2, studlab,
-#'                 data = Senn2013.5, sm = "MD", reference = "plac")
+#'   data = Senn2013.5, sm = "MD", reference = "plac")
 #' 
 #' # Decomposition of Cochran's Q
 #' #
@@ -64,6 +64,7 @@ print.decomp.design <- function(x,
   
   
   chkclass(x, "decomp.design")
+  x <- updateversion(x)
   ##
   chknumeric(digits.Q, min = 0, length = 1)
   chknumeric(digits.pval.Q, min = 0, length = 1)
@@ -186,26 +187,11 @@ print.decomp.design <- function(x,
   print(Q.inc.random)
   
   
-  if (legend) {
-    trts1.abbr <- treats(trts1, nchar.trts)
-    trts2.abbr <- treats(trts2, nchar.trts)
-    ##
-    diff.trts1 <- trts1 != trts1.abbr
-    diff.trts2 <- trts2 != trts2.abbr
-    if (any(diff.trts1) | any(diff.trts2)) {
-      cat("\nLegend:\n")
-      ##
-      trts <- c(trts1, trts2)
-      trts.abbr <- c(trts1.abbr, trts2.abbr)
-      tmat <- data.frame(trts.abbr, trts)
-      tmat <- tmat[diff.trts1 | diff.trts2, ]
-      names(tmat) <- c("Abbreviation", "Treatment name")
-      tmat <- tmat[order(tmat$Abbreviation), ]
-      ##
-      prmatrix(unique(tmat), quote = FALSE, right = TRUE,
-               rowlab = rep("", nrow(unique(tmat))))
-    }
-  }
+  ##
+  ## Add legend with abbreviated treatment labels
+  ##
+  trts <- unique(c(trts1, trts2))
+  legendabbr(trts, treats(trts, nchar.trts), legend)
   
   
   invisible(NULL)
